<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 02/13/2005 *
 * ===================                          Last change: 02/13/2005 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : doubler.php                                      *
 * -------------------------------------------------------------------- *
 * Short description : Points doubler                                   *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Punkteverdoppler                                 *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Load security stuff here
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['startTime'] = microtime(true);

// Set module
$GLOBALS['__module'] = 'doubler';
$GLOBALS['output_mode'] = '0';

// Load the required file(s)
require('inc/config-global.php');

// Set content type
setContentType('text/html');

// Is the 'doubler' extension active?
redirectOnUninstalledExtension('doubler');

// Init content array
$content = array(
	'message' => '',
);

// Begin with doubler script...
if (isFormSent()) {
	// Secure points (so only integer/double values are allowed
	setPostRequestElement('points', bigintval(postRequestElement('points')));

	// Begin with doubling process
	if ((isPostRequestElementSet('userid')) && (isPostRequestElementSet('password')) && (isPostRequestElementSet('points'))) {
		// Probe for nickname extension and if a nickname was entered
		if (isNicknameUsed(postRequestElement('userid'))) {
			// Nickname in URL, so load the id
			fetchUserData(postRequestElement('userid'), 'nickname');
		} else {
			// Direct userid entered
			fetchUserData(postRequestElement('userid'));
		}

		// Is the data valid?
		if (!isUserDataValid()) {
			// Output message that the userid is not okay
			displayMessage('{--DOUBLER_USERID_INVALID--}');
		} // END - if

		// Remove any dots and unwanted chars from the points
		setPostRequestElement('points', bigintval(round(convertCommaToDot(postRequestElement('points')))));

		// Probe for enough points
		$probe_points = ((postRequestElement('points') >= getConfig('doubler_min')) && (postRequestElement('points') <= getConfig('doubler_max')));

		// Check all together
		if ((isUserDataValid()) && (getUserData('password') == generateHash(postRequestElement('password'), substr(getUserData('password'), 0, -40))) && (getUserData('status') == 'CONFIRMED') && ($probe_points)) {
			// Nickname resolved to a unique userid or direct userid entered by the member
			$GLOBALS['local_doubler_userid'] = getUserData('userid');

			// Calulcate points
			$points = getTotalPoints(getUserData('userid'));

			// So let's continue with probing his points amount
			if (($points - getConfig('doubler_left') - postRequestElement('points') * getConfig('doubler_charge') / 100) >= 0) {
				// Enough points are left so let's continue with the doubling process
				// Create doubling "account" with *DOUBLED* points
				SQL_QUERY_ESC("INSERT INTO `{?_MYSQL_PREFIX?}_doubler` (`userid`,`refid`,`points`,`remote_ip`,`timemark`,`completed`,`is_ref`) VALUES (%s,%s,%s,'%s', UNIX_TIMESTAMP(), 'N','N')",
					array(
						getUserData('userid'),
						convertZeroToNull(determineReferralId()),
						bigintval(postRequestElement('points') * 2),
						detectRemoteAddr()
					), __FILE__, __LINE__);

				// Subtract entered points and ignore return status
				subtractPoints('doubler', getUserData('userid'), postRequestElement('points'));

				// Add points to "total payed" including charge
				$points = postRequestElement('points') - postRequestElement('points') * getConfig('doubler_charge') / 100;
				updateConfiguration('doubler_points', $points, '+');
				incrementConfigEntry('doubler_points', $points);

				// Add second line for the referral but only when userid != refid
				if ((isValidUserId(determineReferralId())) && (determineReferralId() != getUserData('userid'))) {
					// Okay add a refid line and apply refid percents
					SQL_QUERY_ESC("INSERT INTO `{?_MYSQL_PREFIX?}_doubler` (`userid`,`refid`,`points`,`remote_ip`,`timemark`,`completed`,`is_ref`) VALUES (%s,0,%s,'%s',UNIX_TIMESTAMP(),'N','Y')",
						array(
							convertZeroToNull(determineReferralId()),
							(postRequestElement('points') * 2 * getConfig('doubler_ref') / 100),
							detectRemoteAddr()
						), __FILE__, __LINE__);

					// And that's why we don't want to you more than one referral level of doubler-points. ^^^
				} // END - if

				// Update usage counter
				updateConfiguration('doubler_counter', 1, '+');

				// Set constant
				$content['message'] = loadTemplate('doubler_reflink', true, postRequestElement('userid'));
			} else {
				// Not enougth points left
				$content['message'] = '{--DOUBLER_FORM_NO_POINTS_LEFT--}';
			}
		} elseif (getUserData('status') == 'CONFIRMED') {
			// Account is unconfirmed!
			$content['message'] = '{--DOUBLER_FORM_WRONG_PASS--}';
		} elseif (getUserData('status') == 'UNCONFIRMED') {
			// Account is unconfirmed!
			$content['message'] = '{--DOUBLER_FORM_STATUS_UNCONFIRMED--}';
		} elseif (getUserData('status') == 'LOCKED') {
			// Account is locked by admin / holiday!
			$content['message'] = '{--DOUBLER_FORM_STATUS_LOCKED--}';
		} elseif (postRequestElement('points') < getConfig('doubler_min')) {
			// Not enougth points entered
			$content['message'] = '{--DOUBLER_FORM_POINTS_MIN--}';
		} elseif (postRequestElement('points') > getConfig('doubler_max')) {
			// Too much points entered
			$content['message'] = '{--DOUBLER_FORM_POINTS_MAX--}';
		} elseif (isNicknameUsed(postRequestElement('userid'))) {
			// Cannot resolv nickname -> userid
			$content['message'] = '{--DOUBLER_FORM_404_NICKNAME--}';
		} else {
			// Wrong password or account not found
			$content['message'] = '{--DOUBLER_FORM_404_MEMBER--}';
		}
	} elseif (!isPostRequestElementSet('userid')) {
		// Login not entered
		$content['message'] = '{--DOUBLER_FORM_404_LOGIN--}';
	} elseif (!isPostRequestElementSet('password')) {
		// Password not entered
		$content['message'] = '{--DOUBLER_FORM_404_PASSWORD--}';
	} elseif (!isPostRequestElementSet('points')) {
		// points not entered
		$content['message'] = '{--DOUBLER_FORM_404_POINTS--}';
	}
} // END - if (isFormSet())

// Shall I check for points immediately?
if (getConfig('doubler_send_mode') == 'DIRECT') {
	loadInclude('inc/mails/doubler_mails.php');
} // END - if

// Output header
loadIncludeOnce('inc/header.php');

// Banner in text
$content['banner'] = loadTemplate('doubler_banner', true);

// Load header/footer templates
$content['header'] = loadTemplate('doubler_header', true);
$content['footer'] = loadTemplate('doubler_footer', true);

if (isUserDataValid()) {
	// Transfer userid/nickname to constant
	$content['refid'] = getUserData('userid');
} else {
	// Transfer userid/nickname to constant
	$content['refid'] = determineReferralId();
}

// Text "Enter login"
if (isExtensionActive('nickname')) {
	// Choose login/nickname
	$content['enter_login'] = '{--GUEST_ENTER_LOGIN_NICKNAME--}';
} else {
	// Simple login id
	$content['enter_login'] = '{--GUEST_ENTER_LOGIN--}';
}

// Which mail-send-mode did the admin setup?
$content['payout_time'] = '{--DOUBLER_PAYOUT_TIME_' . getConfig('doubler_send_mode') . '--}';

// Generate table with already payed out doubles
$content['payout_history'] = generateDoublerTable(0, 'Y', 'N', 'DESC');

// Output neccessary form for this
loadTemplate('doubler_index', false, $content);

// Output footer
loadIncludeOnce('inc/footer.php');

// [EOF]
?>
